==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/el-GR/admin/licenses/message.php <==
<?php

return array(

    'does_not_exist' => 'Η άδεια δεν υπάρχει ή δεν έχετε άδεια για να την δείτε.',
    'user_does_not_exist' => 'Ο χρήστης δεν υπάρχει.',
    'asset_does_not_exist' 	=> 'Το πάγιο που προσπαθείτε να συσχετίσετε με αυτήν την άδεια δεν υπάρχει.',
    'owner_doesnt_match_asset' => 'Το περιουσιακό στοιχείο που προσπαθείτε να συσχετίσετε με αυτήν την άδεια ανήκει σε κάποιον άλλον εκτός από το άτομο που επιλέχθηκε στο αναπτυσσόμενο μενού.',
    'assoc_users'	 => 'Αυτήν τη στιγμή, αυτή η άδεια χρήσης αποστέλλεται στον χρήστη και δεν μπορεί να διαγραφεί. Ελέγξτε πρώτα την άδεια χρήσης και δοκιμάστε ξανά τη διαγραφή.',
    'select_asset_or_person' => 'Πρέπει να επιλέξετε ένα στοιχείο ή έναν χρήστη, αλλά όχι και τα δύο.',
    'not_found' => 'Η άδεια δεν βρέθηκε',
    'seats_available' => ':seat_count διαθέσιμες θέσεις',


    'create' => array(
        'error'   => 'Η άδεια δεν δημιουργήθηκε, παρακαλώ προσπαθήστε ξανά.',
        'success' => 'Η άδεια δημιουργήθηκε με επιτυχία.'
    ),

    'deletefile' => array(
        'error'   => 'Ο φάκελος έχει διαγραφεί. Παρακαλώ δοκιμάστε ξανά.',
        'success' => 'Το αρχείο διαγράφηκε με επιτυχία.',
    ),

    'upload' => array(
        'error'   => 'Τα αρχεία δεν μεταφορτώθηκαν. Παρακαλώ δοκιμάστε ξανά.',
        'success' => 'Τα αρχεία ενημερώθηκαν με επιτυχία.',
        'nofiles' => 'Δεν επιλέξατε κανένα αρχείο για μεταφόρτωση ή το αρχείο που προσπαθείτε να μεταφορτώσετε είναι πολύ μεγάλο',
        'invalidfiles' => 'Ένα ή περισσότερα από τα αρχεία σας είναι πολύ μεγάλα ή είναι τύπου αρχείου που δεν επιτρέπεται. Οι επιτρεπόμενοι τύποι αρχείων είναι png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, rar, rtf, xml και lic.',
    ),

    'update' => array(
        'error'   => 'Η άδεια δεν δημιουργήθηκε, παρακαλώ προσπαθήστε ξανά',
        'success' => 'Η άδεια ενημερώθηκε με επιτυχία.'
    ),

    'delete' => array(
        'confirm'   => 'Είστε σίγουροι ότι θέλετε να διαγράψετε αυτή την άδεια;',
        'error'   => 'Υπήρξε ένα ζήτημα διαγράφοντας την άδεια. Παρακαλώ δοκιμάστε ξανά.',
        'success' => 'Η άδεια διαγράφηκε επιτυχώς.'
    ),

    'checkout' => array(
        'error'   => 'Παρουσιάστηκε πρόβλημα κατά την εξακρίβωση της άδειας. ΠΑΡΑΚΑΛΩ προσπαθησε ξανα.',
        'success' => 'Η άδεια εκτυπώθηκε με επιτυχία',
        'not_enough_seats' => 'Δεν υπάρχουν αρκετές θέσεις άδειας χρήσης για ολοκλήρωση της παραγγελίας',
    ),

    'checkin' => array(
        'error'   => 'Παρουσιάστηκε ένα ζήτημα ελέγχου της άδειας. ΠΑΡΑΚΑΛΩ προσπαθησε ξανα.',
        'success' => 'Η άδεια έχει ελεγχθεί με επιτυχία'
    ),

);

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/el-GR/admin/licenses/message.php <==
<?php

return array(

    'does_not_exist' => 'Η άδεια δεν υπάρχει ή δεν έχετε άδεια για να την δείτε.',
    'user_does_not_exist' => 'Ο χρήστης δεν υπάρχει ή δεν έχετε δικαίωμα να τον δείτε.',
    'asset_does_not_exist' 	=> 'Το πάγιο που προσπαθείτε να συσχετίσετε με αυτήν την άδεια δεν υπάρχει.',
    'owner_doesnt_match_asset' => 'Το περιουσιακό στοιχείο που προσπαθείτε να συσχετίσετε με αυτήν την άδεια ανήκει σε κάποιον άλλον εκτός από το άτομο που επιλέχθηκε στο αναπτυσσόμενο μενού.',
    'assoc_users'	 => 'Αυτήν τη στιγμή, αυτή η άδεια χρήσης αποστέλλεται στον χρήστη και δεν μπορεί να διαγραφεί. Ελέγξτε πρώτα την άδεια χρήσης και δοκιμάστε ξανά τη διαγραφή.',
    'select_asset_or_person' => 'Πρέπει να επιλέξετε ένα στοιχείο ή έναν χρήστη, αλλά όχι και τα δύο.',
    'not_found' => 'Η άδεια δεν βρέθηκε',
    'seats_available' => ':seat_count διαθέσιμες θέσεις',


    'create' => array(
        'error'   => 'Η άδεια δεν δημιουργήθηκε, παρακαλώ προσπαθήστε ξανά.',
        'success' => 'Η άδεια δημιουργήθηκε με επιτυχία.'
    ),

    'deletefile' => array(
        'error'   => 'Ο φάκελος έχει διαγραφεί. Παρακαλώ δοκιμάστε ξανά.',
        'success' => 'Το αρχείο διαγράφηκε με επιτυχία.',
    ),

    'upload' => array(
        'error'   => 'Τα αρχεία δεν μεταφορτώθηκαν. Παρακαλώ δοκιμάστε ξανά.',
        'success' => 'Τα αρχεία ενημερώθηκαν με επιτυχία.',
        'nofiles' => 'Δεν επιλέξατε κανένα αρχείο για μεταφόρτωση ή το αρχείο που προσπαθείτε να μεταφορτώσετε είναι πολύ μεγάλο',
        'invalidfiles' => 'Ένα ή περισσότερα από τα αρχεία σας είναι πολύ μεγάλα ή είναι τύπου αρχείου που δεν επιτρέπεται. Οι επιτρεπόμενοι τύποι αρχείων είναι png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, rar, rtf, xml και lic.',
    ),

    'update' => array(
        'error'   => 'Η άδεια δεν δημιουργήθηκε, παρακαλώ προσπαθήστε ξανά',
        'success' => 'Η άδεια ενημερώθηκε με επιτυχία.'
    ),

    'delete' => array(
        'confirm'   => 'Είστε σίγουροι ότι θέλετε να διαγράψετε αυτή την άδεια;',
        'error'   => 'Υπήρξε ένα ζήτημα διαγράφοντας την άδεια. Παρακαλώ δοκιμάστε ξανά.',
        'success' => 'Η άδεια διαγράφηκε επιτυχώς.'
    ),

    'checkout' => array(
        'error'   => 'Παρουσιάστηκε πρόβλημα κατά την εξακρίβωση της άδειας. ΠΑΡΑΚΑΛΩ προσπαθησε ξανα.',
        'success' => 'Η άδεια εκτυπώθηκε με επιτυχία',
        'not_enough_seats' => 'Δεν υπάρχουν αρκετές θέσεις άδειας χρήσης για ολοκλήρωση της παραγγελίας',
        'mismatch' => 'The license seat provided does not match the license',
        'unavailable' => 'This seat is not available for checkout.',
    ),

    'checkin' => array(
        'error'   => 'Παρουσιάστηκε ένα ζήτημα ελέγχου της άδειας. ΠΑΡΑΚΑΛΩ προσπαθησε ξανα.',
        'success' => 'Η άδεια έχει ελεγχθεί με επιτυχία'
    ),

);
